@@ -258,7 +258,9 @@ generated by running puppet agent with '--genconfig'.
 
 * --job-id:
   Attach the specified job id to the catalog request and the report used for
-  this agent run. This option only works when '--onetime' is used.
+  this agent run. This option only works when '--onetime' is used.  When using
+  Puppet Enterprise this flag should not be used as the orchestrator sets the
+  job-id for you and it must be unique.
 
 * --logdest:
   Where to send log messages. Choose between 'syslog' (the POSIX syslog
@@ -363,8 +365,17 @@ Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
       daemon.set_signal_traps
 
       log_config if Puppet[:daemonize]
-      
-      Puppet.override(ssl_context: wait_for_certificates) do
+
+      # run ssl state machine, waiting if needed
+      ssl_context = wait_for_certificates
+
+      # Each application is responsible for pushing loaders onto the context.
+      # Use the current environment that has already been established, though
+      # it may change later during the configurer run.
+      env = Puppet.lookup(:current_environment)
+      Puppet.override(ssl_context: ssl_context,
+                      current_environment: env,
+                      loaders: Puppet::Pops::Loaders.new(env, true)) do
         if Puppet[:onetime]
           onetime(daemon)
         else
