@@ -4,8 +4,7 @@ require 'puppet/util'
 # The base class for JSON indirection terminus implementations.
 #
 # This should generally be preferred to the YAML base for any future
-# implementations, since it is ~ three times faster despite being pure Ruby
-# rather than a C implementation.
+# implementations, since it is faster and can load untrusted data safely.
 class Puppet::Indirector::JSON < Puppet::Indirector::Terminus
   def find(request)
     load_json_from_file(path(request.key), request.key)
@@ -15,16 +14,16 @@ class Puppet::Indirector::JSON < Puppet::Indirector::Terminus
     filename = path(request.key)
     FileUtils.mkdir_p(File.dirname(filename))
 
-    Puppet::Util.replace_file(filename, 0660) {|f| f.print to_json(request.instance).force_encoding(Encoding::ASCII_8BIT) }
+    Puppet::FileSystem.replace_file(filename, 0660) {|f| f.print to_json(request.instance).force_encoding(Encoding::BINARY) }
   rescue TypeError => detail
-    Puppet.log_exception(detail, "Could not save #{self.name} #{request.key}: #{detail}")
+    Puppet.log_exception(detail, _("Could not save %{json} %{request}: %{detail}") % { json: self.name, request: request.key, detail: detail })
   end
 
   def destroy(request)
     Puppet::FileSystem.unlink(path(request.key))
   rescue => detail
     unless detail.is_a? Errno::ENOENT
-      raise Puppet::Error, "Could not destroy #{self.name} #{request.key}: #{detail}", detail.backtrace
+      raise Puppet::Error, _("Could not destroy %{json} %{request}: %{detail}") % { json: self.name, request: request.key, detail: detail }, detail.backtrace
     end
     1                           # emulate success...
   end
@@ -38,8 +37,8 @@ class Puppet::Indirector::JSON < Puppet::Indirector::Terminus
   # Return the path to a given node's file.
   def path(name, ext = '.json')
     if name =~ Puppet::Indirector::BadNameRegexp then
-      Puppet.crit("directory traversal detected in #{self.class}: #{name.inspect}")
-      raise ArgumentError, "invalid key"
+      Puppet.crit(_("directory traversal detected in %{json}: %{name}") % { json: self.class, name: name.inspect })
+      raise ArgumentError, _("invalid key")
     end
 
     base = Puppet.run_mode.master? ? Puppet[:server_datadir] : Puppet[:client_datadir]
@@ -52,25 +51,25 @@ class Puppet::Indirector::JSON < Puppet::Indirector::Terminus
     json = nil
 
     begin
-      json = Puppet::FileSystem.read(file).force_encoding(Encoding::ASCII_8BIT)
+      json = Puppet::FileSystem.read(file, :encoding => Encoding::BINARY)
     rescue Errno::ENOENT
       return nil
     rescue => detail
-      raise Puppet::Error, "Could not read JSON data for #{indirection.name} #{key}: #{detail}", detail.backtrace
+      raise Puppet::Error, _("Could not read JSON data for %{name} %{key}: %{detail}") % { name: indirection.name, key: key, detail: detail }, detail.backtrace
     end
 
     begin
       return from_json(json)
     rescue => detail
-      raise Puppet::Error, "Could not parse JSON data for #{indirection.name} #{key}: #{detail}", detail.backtrace
+      raise Puppet::Error, _("Could not parse JSON data for %{name} %{key}: %{detail}") % { name: indirection.name, key: key, detail: detail }, detail.backtrace
     end
   end
 
   def from_json(text)
-    model.convert_from('pson', text)
+    model.convert_from('json', text.force_encoding(Encoding::UTF_8))
   end
 
   def to_json(object)
-    object.render('pson')
+    object.render('json')
   end
 end
