@@ -12,6 +12,7 @@ class TypedName
   attr_reader :compound_name
 
   def initialize(type, name, name_authority = Pcore::RUNTIME_NAME_AUTHORITY)
+    name = name.downcase
     @type = type
     @name_authority = name_authority
     # relativize the name (get rid of leading ::), and make the split string available
@@ -36,6 +37,11 @@ class TypedName
 
   alias eql? ==
 
+  # @return the parent of this instance, or nil if this instance is not qualified
+  def parent
+    @name_parts.size > 1 ? self.class.new(@type, @name_parts[0...-1].join(DOUBLE_COLON), @name_authority) : nil
+  end
+
   def qualified?
     @name_parts.size > 1
   end
