@@ -26,21 +26,20 @@ module Util
 
   extend Puppet::Util::SymbolicFileMode
 
-  def default_env
-    Puppet::Util::Platform.windows? ?
-      :windows :
-      :posix
-  end
-  module_function :default_env
+  DEFAULT_ENV = if Puppet::Util::Platform.windows?
+                  :windows
+                else
+                  :posix
+                end.freeze
 
   # @param name [String] The name of the environment variable to retrieve
   # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
   # @return [String] Value of the specified environment variable.  nil if it does not exist
   # @api private
-  def get_env(name, mode = default_env)
+  def get_env(name, mode = DEFAULT_ENV)
     if mode == :windows
-      Puppet::Util::Windows::Process.get_environment_strings.each do |key, value |
-        if name.casecmp(key) == 0 then
+      Puppet::Util::Windows::Process.get_environment_strings.find do |key, value|
+        if name.casecmp(key) == 0
           return value
         end
       end
@@ -54,7 +53,7 @@ module Util
   # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
   # @return [Hash] A hashtable of all environment variables
   # @api private
-  def get_environment(mode = default_env)
+  def get_environment(mode = DEFAULT_ENV)
     case mode
       when :posix
         ENV.to_hash
@@ -69,7 +68,7 @@ module Util
   # Removes all environment variables
   # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
   # @api private
-  def clear_environment(mode = default_env)
+  def clear_environment(mode = DEFAULT_ENV)
     case mode
       when :posix
         ENV.clear
@@ -87,7 +86,7 @@ module Util
   # @param value [String] The value to set the variable to.  nil deletes the environment variable
   # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
   # @api private
-  def set_env(name, value = nil, mode = default_env)
+  def set_env(name, value = nil, mode = DEFAULT_ENV)
     case mode
       when :posix
         ENV[name] = value
@@ -102,7 +101,7 @@ module Util
   # @param name [Hash] Environment variables to merge into the existing environment.  nil values will remove the variable
   # @param mode [Symbol] Which operating system mode to use e.g. :posix or :windows.  Use nil to autodetect
   # @api private
-  def merge_environment(env_hash, mode = default_env)
+  def merge_environment(env_hash, mode = DEFAULT_ENV)
     case mode
       when :posix
         env_hash.each { |name, val| ENV[name.to_s] = val }
@@ -296,6 +295,11 @@ module Util
   AbsolutePathWindows = %r!^(?:(?:[A-Z]:#{slash})|(?:#{slash}#{slash}#{label}#{slash}#{label})|(?:#{slash}#{slash}\?#{slash}#{label}))!io
   AbsolutePathPosix   = %r!^/!
   def absolute_path?(path, platform=nil)
+    unless path.is_a?(String)
+      Puppet.warning("Cannot check if #{path} is an absolute path because it is a '#{path.class}' and not a String'")
+      return false
+    end
+
     # Ruby only sets File::ALT_SEPARATOR on Windows and the Ruby standard
     # library uses that to test what platform it's on.  Normally in Puppet we
     # would use Puppet.features.microsoft_windows?, but this method needs to
